from django.core.management import execute_from_command_line
from django.core.management.utils import get_random_secret_key
from pathlib import Path

DIR_PROJECT_TEMPLATE = Path(__file__).parent / "project_template"


def main():
    project_name = input("project_name [config]: ").strip() or "config"
    execute_from_command_line([
        "django-admin",
        "startproject",
        "--template",
        str(DIR_PROJECT_TEMPLATE),
        str(project_name),
        ".",
    ])
    print(f'SECRET_KEY = "{get_random_secret_key()}"')


if __name__ == "__main__":
    main()



from .base import *

DEBUG = True
SECRET_KEY = "Fake Key"

# django-debug-toolbar
INSTALLED_APPS += ["debug_toolbar"]
MIDDLEWARE += ["debug_toolbar.middleware.DebugToolbarMiddleware"]
DEBUG_TOOLBAR_CONFIG = {
    "SHOW_TEMPLATE_CONTEXT": True,
}
INTERNAL_IPS = ["127.0.0.1", "10.0.2.2"]



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['djplus',
 'djplus.project_template',
 'djplus.project_template.project_name',
 'djplus.project_template.project_name.settings']

package_data = \
{'': ['*']}

install_requires = \
['Django>=4.0.3,<5.0.0']

entry_points = \
{'console_scripts': ['djplus = djplus.__main__:main']}

setup_kwargs = {
    'name': 'jommerce',
    'version': '1.0.0.post0',
    'description': 'django ready apps',
    'long_description': '# djplus',
    'author': 'githashem',
    'author_email': 'PersonalHashem@gmail.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'https://github.com/githashem/djplus',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
